#include "PreCompile.h" //apt

#include "AptF.h"
#include "ui_AptF.h"

AptF::AptF(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::AptF)
{
    ui->setupUi(this);

    ui->PkgNmlineEdit->setFocus(); //焦点放到软件包名字输入框中。


    connect(&AptPrc,SIGNAL(readyRead()),this,SLOT(ShowAptOutput())); //apt-get有内容输出，则显示。
    connect(&AptPrc,SIGNAL(readyReadStandardError()),this,SLOT(ShowAptOutputStdErr())); //apt-get有标准错误流输出，则显示。
}

AptF::~AptF()
{
    delete ui;
}

/*!
 * \brief AptF::Install 安装。
 */
void AptF::Install()
{
    //获取软件包的名字，再调用apt来安装。

    //获取软件包名字：
    QString Pkg2Ist=ui->PkgNmlineEdit->text(); //获取软件包名字。

    //安装：
    QStringList AptPrms; //命令行参数。
    AptPrms << "-q" << "install" << Pkg2Ist; //加入软件包名字。
    AptPrc.start(AptCmd,AptPrms); //启动进程。

    return;
} //void AptF::Install() //!<安装。

/*!
 * \brief AptF::ShowAptOutput apt-get有内容输出，则显示。
 */
void AptF::ShowAptOutput()
{
    QString Otpt=AptPrc.readAll(); //读入所有输出。

    ui->OtptplainTextEdit->appendPlainText(Otpt); //显示。

    if (Otpt.contains("Do you want to continue? [Y/n]")) //有询问语句。
    {
        qDebug() << __FILE__ << __LINE__ << __func__ ; //Debug.
        QMessageBox::StandardButton Ctn=QMessageBox::question(this,tr("AptF question"),tr("Please read the output and decide whether we should continue the operation"),QMessageBox::Yes | QMessageBox::No); //询问。

        if (Ctn==QMessageBox::Yes) //要继续操作，则输入Y。
        {
            AptPrc.write("Y\n"); //输入Y。
        } //if (Ctn==QMessageBox::Yes) //要继续操作，则输入Y。
        else //拒绝继续操作。
        {
            AptPrc.write("n\n"); //输入n。
        } //else //拒绝继续操作。
    } //if (Otpt.contains("Do you want to continue? [Y/n]")) //有询问语句。
    else if (Otpt.contains("To continue type in the phrase 'Yes, do as I say!'")) //有询问语句。
    {
        QMessageBox::StandardButton Ctn=QMessageBox::warning(this,tr("AptF warning"),tr("You're going to do something really harmful.Please read the output and decide whether we should continue the operation"),QMessageBox::Yes | QMessageBox::No); //询问。

        if (Ctn==QMessageBox::Yes) //要继续操作，则输入Y。
        {
            AptPrc.write("Yes, do as I say!\n"); //输入Yes, do as I say!。
        } //if (Ctn==QMessageBox::Yes) //要继续操作，则输入Y。
        else //拒绝继续操作。
        {
            AptPrc.write("n\n"); //输入n。
        } //else //拒绝继续操作。

    } //else if (Otpt.contains("To continue type in the phrase 'Yes, do as I say!'")) //有询问语句。

    return;
} //void AptF::ShowAptOutput() //!<apt-get有内容输出，则显示。

/*!
 * \brief AptF::ShowAptOutputStdErr apt-get有标准错误流输出，则显示。
 */
void AptF::ShowAptOutputStdErr()
{
    QString Otpt=AptPrc.readAllStandardError(); //读入所有输出。

    ui->OtptplainTextEdit->appendPlainText(Otpt); //显示。

    //如果其中有询问语句，则弹出询问对话框：
    qDebug() << __FILE__ << __LINE__ << __func__ ; //Debug.

    return;
} //void AptF::ShowAptOutputStdErr() //!<apt-get有标准错误流输出，则显示。

/*!
 * \brief AptF::Upgrade 升级。
 */
void AptF::Upgrade()
{
    QStringList AptPrms; //命令行参数。
    AptPrms << "upgrade"; //加入升级命令。
    AptPrc.start(AptCmd,AptPrms); //启动进程。

    return;
} //void AptF::Upgrade() //!<升级。

/*!
 * \brief AptF::Remove 删除。
 */
void AptF::Remove()
{
    //获取软件包名字：
    QString Pkg2Ist=ui->PkgNmlineEdit_2->text(); //获取软件包名字。

    //删除：
    QStringList AptPrms; //命令行参数。
    AptPrms << "remove" << Pkg2Ist; //加入软件包名字。
    AptPrc.start(AptCmd,AptPrms); //启动进程。

    return;
} //void AptF::Remove() //!<删除。

/*!
 * \brief AptF::AutoFillPkgName 自动填充软件包名。
 */
void AptF::AutoFillPkgName()
{
    ui->PkgNmlineEdit->setText(ui->OtptplainTextEdit->textCursor().selectedText()); //填充到软件包名字输入框中。
    ui->PkgNmlineEdit_2->setText(ui->OtptplainTextEdit->textCursor().selectedText()); //填充到软件包名字输入框中。

    return;
} //void AptF::AutoFillPkgName() //!<自动填充软件包名。

/*!
 * \brief AptF::Update 更新信息。
 */
void AptF::Update()
{
    QStringList AptPrms; //命令行参数。
    AptPrms << "update"; //加入更新命令。
    AptPrc.start(AptCmd,AptPrms); //启动进程。

    return;
} //void AptF::Update() //!<更新信息。

/*!
 * \brief AptF::DistUpgrade 升级发行版。
 */
void AptF::DistUpgrade()
{
    QStringList AptPrms; //命令行参数。
    AptPrms << "dist-upgrade"; //加入升级发行版命令。
    AptPrc.start(AptCmd,AptPrms); //启动进程。

    return;
} //void AptF::DistUpgrade() //!<升级发行版。
